// import Chat, { Bubble, useMessages } from '@chatui/core';
// import '@chatui/core/dist/index.css';
import { useState } from "react";
import {
  Button,
  Col,
  Container,
  Form,
  FormLabel,
  Navbar,
  Row,
  ListGroup
} from "react-bootstrap";
import io from "socket.io-client";
import "../App.css";

const url = 'https://staging.strk-ai-support.ngrok.app/'
// const url = 'http://localhost:8000'

const socket = io(url, {
  extraHeaders: {
    "ngrok-skip-browser-warning": " ",
  },
});

socket.on("connect", (data) => {
  console.log(data);
});

function ChatTrans() {
  const [languageSupport, setLanguageSupport] = useState("English");
  const [languageUser, setLanguageUser] = useState("Simple Chinese");
  const [userMessage, setUserMessage] = useState("");
  const [supportMessage, setSupportMessage] = useState("");
  const [supportName, setSupportName] = useState("");
  const [userName, setUserName] = useState("");

  const [userMessages, setUserMessages] = useState([]);
  const [supportMessages, setSupportMessages] = useState([]);


  socket.on("send msg", function (data) {
    let messge = data.user + ": " + data.message;
    if (data.user === "user") {
      setSupportMessages([...supportMessages, messge]);
    } else {
      setUserMessages([...userMessages, messge]);
    }
  });

  const sendUserMessage = (event, user) => {
    if (userMessage) {
      socket.emit("send msg", {
        user: "user",
        message: userMessage,
        languageSupport: languageSupport,
        languageUser: languageUser,
      });
      setUserMessage("");
      setUserMessages([...userMessages, "user: " +userMessage]);
    } else {
      alert("Message cannot be empty");
    }
  };

  const sendSupportMessage = (event, user) => {
    if (supportMessage) {
      socket.emit("send msg", {
        user: "support",
        message: supportMessage,
        languageSupport: languageSupport,
        languageUser: languageUser,
      });
      setSupportMessage("");
      setSupportMessages([...supportMessages, "support: " + supportMessage]);
    } else {
      alert("Message cannot be empty");
    }
  };

  const setName = () => {
    console.log(supportName);
    console.log(userName);
    if (supportName && userName) {
      socket.emit("set room", {
        support_name: supportName,
        user_name: userName,
      });

      socket.emit("join", {
        username: supportName,
        room: supportName + '-' + userName,
      });
    }
  }

  const onUserKeyDown = function (e) {
    if (e.keyCode == 13) {
        sendUserMessage(e, "user");
    }
  };

  const onSupportKeyDown = function (e) {
    if (e.keyCode == 13) {
        sendSupportMessage(e, "support");
    }
  };

  return (
    <Container>
      <Row>
        <Col>
          <FormLabel>user name</FormLabel>
          <Form.Control
            type="text"
            value={userName}
            onChange={(e) => setUserName(e.target.value)}
            placeholder="Enter user name"
          />
        </Col>
        <Col>
          <FormLabel>support name</FormLabel>
          <Form.Control
            type="text"
            value={supportName}
            onChange={(e) => setSupportName(e.target.value)}
            placeholder="Enter support name"
          />
        </Col>
        <Button onClick={(e) => setName()}>Submit(You should set user name and support name first!)</Button>
      </Row>
      <Row>
        <Col>
          <FormLabel>user</FormLabel>
          <Form.Control
            as="select"
            onChange={(e) => setLanguageUser(e.target.value)}
          >
            <option value="Simplified Chinese">Simplified Chinese</option>
            <option value="Traditional Chinese">Traditional Chinese</option>
            <option value="Italiano">Italiano</option>
            <option value="German">German</option>
            <option value="Japanese">Japanese</option>
            <option value="French">French</option>
            <option value="Arabic">Arabic</option>
            <option value="Spanish">Spanish</option>
            <option value="Dutch">Dutch</option>
            <option value="Portuguese">Portuguese</option>
            <option value="Finnish">Finnish</option>
            <option value="Norwegian">Norwegian</option>
            <option value="Swedish">Swedish</option>
            <option value="Czech">Czech</option>
            <option value="Romanian">Romanian</option>
            <option value="Indonesian">Indonesian</option>
            <option value="Polish">Polish</option>
            <option value="Vietnamese">Vietnamese</option>
            <option value="Korean">Korean</option>
          </Form.Control>
          <Form.Control
            type="text"
            value={userMessage}
            onChange={(e) => setUserMessage(e.target.value)}
            placeholder="Enter message"
            onKeyDown={(e) => onUserKeyDown(e)  }
          />
        </Col>
        <Col>
          <FormLabel>support</FormLabel>
          <Form.Control
            as="select"
            onChange={(e) => setLanguageSupport(e.target.value)}
          >
            <option value="English">English</option>
            <option value="Simplified Chinese">Simplified Chinese</option>
          </Form.Control>
          <Form.Control
            type="text"
            value={supportMessage}
            onChange={(e) => setSupportMessage(e.target.value)}
            placeholder="Enter message"
            onKeyDown={(e) => onSupportKeyDown(e)  }
          />
        </Col>

      <Row>
        <Col>
        <ListGroup variant="flush">
        {userMessages.map((message, index) => (
          <ListGroup.Item key={index}>{message}</ListGroup.Item>
        ))}
      </ListGroup>
        </Col>
        <Col>
        <ListGroup variant="flush">
        {supportMessages.map((message, index) => (
          <ListGroup.Item key={index}>{message}</ListGroup.Item>
        ))}
      </ListGroup>
        </Col>
        </Row>
      

      </Row>
    </Container>
  );
}

export default ChatTrans;
